# CI/CD Guide Redirect

This compatibility page points to the maintained 2.0 checkpoint orchestration guide.

- [Checkpoints](checkpoints.md)
- [Migration to 2.0](migration-2.0.md)
- [Legacy Archive](../legacy/index.md)
